==> elo_indexserver_client-0.1.2.tar.gz: elo_indexserver_client-0.1.2/eloclient/models/b_request_feed_service_checkout_hash_tag.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.client_info import ClientInfo
    from ..models.hash_tag_z import HashTagZ


T = TypeVar("T", bound="BRequestFeedServiceCheckoutHashTag")


@_attrs_define
class BRequestFeedServiceCheckoutHashTag:
    """
    Attributes:
        ci (Union[Unset, ClientInfo]): Contains the session ticket and the users language and country.
            Each Indexserver interface function, except the
             login, requires a <code>ClientInfo</code> object as parameter with a valid session ticket.
             <p>
             Copyright: Copyright (c) 2004
             </p>
             <p>
             Organisation: ELO Digital Office GmbH
             </p>
        hashtag_guid_or_name (Union[Unset, str]):
        hstg_z (Union[Unset, HashTagZ]):
    """

    ci: Union[Unset, "ClientInfo"] = UNSET
    hashtag_guid_or_name: Union[Unset, str] = UNSET
    hstg_z: Union[Unset, "HashTagZ"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        ci: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.ci, Unset):
            ci = self.ci.to_dict()

        hashtag_guid_or_name = self.hashtag_guid_or_name
        hstg_z: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.hstg_z, Unset):
            hstg_z = self.hstg_z.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if ci is not UNSET:
            field_dict["ci"] = ci
        if hashtag_guid_or_name is not UNSET:
            field_dict["hashtagGuidOrName"] = hashtag_guid_or_name
        if hstg_z is not UNSET:
            field_dict["hstgZ"] = hstg_z

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.client_info import ClientInfo
        from ..models.hash_tag_z import HashTagZ

        d = src_dict.copy()
        _ci = d.pop("ci", UNSET)
        ci: Union[Unset, ClientInfo]
        if isinstance(_ci, Unset):
            ci = UNSET
        else:
            ci = ClientInfo.from_dict(_ci)

        hashtag_guid_or_name = d.pop("hashtagGuidOrName", UNSET)

        _hstg_z = d.pop("hstgZ", UNSET)
        hstg_z: Union[Unset, HashTagZ]
        if isinstance(_hstg_z, Unset):
            hstg_z = UNSET
        else:
            hstg_z = HashTagZ.from_dict(_hstg_z)

        b_request_feed_service_checkout_hash_tag = cls(
            ci=ci,
            hashtag_guid_or_name=hashtag_guid_or_name,
            hstg_z=hstg_z,
        )

        b_request_feed_service_checkout_hash_tag.additional_properties = d
        return b_request_feed_service_checkout_hash_tag

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> elo_indexserver_client-0.1.30.tar.gz: elo_indexserver_client-0.1.30/eloclient/models/b_request_feed_service_checkout_hash_tag.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.client_info import ClientInfo
    from ..models.hash_tag_z import HashTagZ


T = TypeVar("T", bound="BRequestFeedServiceCheckoutHashTag")


@_attrs_define
class BRequestFeedServiceCheckoutHashTag:
    """
    Attributes:
        hstg_z (Union[Unset, HashTagZ]):
        ci (Union[Unset, ClientInfo]): Contains the session ticket and the users language and country.
            Each Indexserver interface
             function, except the login, requires a <code>ClientInfo</code> object as parameter with a valid
             session ticket.
             <p>
             Copyright: Copyright (c) 2004
             </p>
             <p>
             Organisation: ELO Digital Office GmbH
             </p>
        hashtag_guid_or_name (Union[Unset, str]):
    """

    hstg_z: Union[Unset, "HashTagZ"] = UNSET
    ci: Union[Unset, "ClientInfo"] = UNSET
    hashtag_guid_or_name: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        hstg_z: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.hstg_z, Unset):
            hstg_z = self.hstg_z.to_dict()

        ci: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.ci, Unset):
            ci = self.ci.to_dict()

        hashtag_guid_or_name = self.hashtag_guid_or_name

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if hstg_z is not UNSET:
            field_dict["hstgZ"] = hstg_z
        if ci is not UNSET:
            field_dict["ci"] = ci
        if hashtag_guid_or_name is not UNSET:
            field_dict["hashtagGuidOrName"] = hashtag_guid_or_name

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.client_info import ClientInfo
        from ..models.hash_tag_z import HashTagZ

        d = src_dict.copy()
        _hstg_z = d.pop("hstgZ", UNSET)
        hstg_z: Union[Unset, HashTagZ]
        if isinstance(_hstg_z, Unset):
            hstg_z = UNSET
        else:
            hstg_z = HashTagZ.from_dict(_hstg_z)

        _ci = d.pop("ci", UNSET)
        ci: Union[Unset, ClientInfo]
        if isinstance(_ci, Unset):
            ci = UNSET
        else:
            ci = ClientInfo.from_dict(_ci)

        hashtag_guid_or_name = d.pop("hashtagGuidOrName", UNSET)

        b_request_feed_service_checkout_hash_tag = cls(
            hstg_z=hstg_z,
            ci=ci,
            hashtag_guid_or_name=hashtag_guid_or_name,
        )

        b_request_feed_service_checkout_hash_tag.additional_properties = d
        return b_request_feed_service_checkout_hash_tag

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
